==> nektar%2B%2B-5.4.0.tar.xz: nektar-v5.4.0/library/FieldUtils/OutputModules/OutputPts.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: OutputPts.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2016 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Pts output module
//
////////////////////////////////////////////////////////////////////////////////

#ifndef FIELDUTILS_OUTPUTPTS
#define FIELDUTILS_OUTPUTPTS

#include "OutputFileBase.h"
#include <tinyxml.h>

namespace Nektar
{
namespace FieldUtils
{

/// Converter from fld to pts.
class OutputPts : public OutputFileBase
{
public:
    /// Creates an instance of this class
    static std::shared_ptr<Module> create(FieldSharedPtr f)
    {
        return MemoryManager<OutputPts>::AllocateSharedPtr(f);
    }
    static ModuleKey m_className[];

    OutputPts(FieldSharedPtr f);
    virtual ~OutputPts();

protected:
    virtual std::string v_GetModuleName() override
    {
        return "OutputPts";
    }

    /// Write from pts to output file.
    virtual void v_OutputFromPts(po::variables_map &vm) override;

    /// Write from m_exp to output file.
    virtual void v_OutputFromExp(po::variables_map &vm) override;

    /// Write from data to output file.
    virtual void v_OutputFromData(po::variables_map &vm) override;

    virtual fs::path v_GetPath(std::string &filename,
                               po::variables_map &vm) override;

    virtual fs::path v_GetFullOutName(std::string &filename,
                                      po::variables_map &vm) override;
};
} // namespace FieldUtils
} // namespace Nektar

#endif

==> nektar%2B%2B-5.7.0.tar.xz: nektar-v5.7.0/library/FieldUtils/OutputModules/OutputPts.h <==
////////////////////////////////////////////////////////////////////////////////
//
//  File: OutputPts.h
//
//  For more information, please see: http://www.nektar.info/
//
//  The MIT License
//
//  Copyright (c) 2016 Division of Applied Mathematics, Brown University (USA),
//  Department of Aeronautics, Imperial College London (UK), and Scientific
//  Computing and Imaging Institute, University of Utah (USA).
//
//  Permission is hereby granted, free of charge, to any person obtaining a
//  copy of this software and associated documentation files (the "Software"),
//  to deal in the Software without restriction, including without limitation
//  the rights to use, copy, modify, merge, publish, distribute, sublicense,
//  and/or sell copies of the Software, and to permit persons to whom the
//  Software is furnished to do so, subject to the following conditions:
//
//  The above copyright notice and this permission notice shall be included
//  in all copies or substantial portions of the Software.
//
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
//  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
//  THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
//  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
//  DEALINGS IN THE SOFTWARE.
//
//  Description: Pts output module
//
////////////////////////////////////////////////////////////////////////////////

#ifndef FIELDUTILS_OUTPUTPTS
#define FIELDUTILS_OUTPUTPTS

#include "OutputFileBase.h"
#include <tinyxml.h>

namespace Nektar::FieldUtils
{

/// Converter from fld to pts.
class OutputPts : public OutputFileBase
{
public:
    /// Creates an instance of this class
    static std::shared_ptr<Module> create(FieldSharedPtr f)
    {
        return MemoryManager<OutputPts>::AllocateSharedPtr(f);
    }
    static ModuleKey m_className[];

    OutputPts(FieldSharedPtr f);
    ~OutputPts() override;

protected:
    std::string v_GetModuleName() override
    {
        return "OutputPts";
    }

    /// Write from pts to output file.
    void v_OutputFromPts(po::variables_map &vm) override;

    /// Write from m_exp to output file.
    void v_OutputFromExp(po::variables_map &vm) override;

    /// Write from data to output file.
    void v_OutputFromData(po::variables_map &vm) override;

    fs::path v_GetPath(std::string &filename, po::variables_map &vm) override;

    fs::path v_GetFullOutName(std::string &filename,
                              po::variables_map &vm) override;
};
} // namespace Nektar::FieldUtils

#endif
